package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.dao.WebPoliciesMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IWebPolicies;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/WebPoliciesService.class */
public class WebPoliciesService implements IWebPolicies {
    private Logger LOG = Logger.getLogger(WebPoliciesService.class);
    private WebPoliciesMapper webPoliciesMapper = (WebPoliciesMapper) InstanceUtil.newDaoInstance(WebPoliciesMapper.class);
    private IEngine engineService = (IEngine) InstanceUtil.newServiceInstance(EngineService.class);

    public int delete(HttpSession session, String id) throws Exception {
        this.engineService.delWebPolicy(id);
        return this.webPoliciesMapper.delete(id, DataRule.getRuleWhere(session, "t_policies"));
    }

    public int searchCount(HttpSession session, String name, String family, String owasp2017, String level, String cve, String cnnvd, String sdate, String edate, Integer type) throws Exception {
        return this.webPoliciesMapper.searchCount(name, family, owasp2017, level, cve, cnnvd, sdate, edate, type, DataRule.getRuleWhere(session, "t_policies"));
    }

    public List<Map<String, Object>> search(HttpSession session, String name, String family, String owasp2017, String level, String cve, String cnnvd, String sdate, String edate, Integer type, Integer offset, Integer limit) throws Exception {
        return this.webPoliciesMapper.search(name, family, owasp2017, level, cve, cnnvd, sdate, edate, type, offset, limit, DataRule.getRuleWhere(session, "t_policies"));
    }

    public String insert(HttpSession session, String name, String family, String owasp2017, String level, String cwe, String cve, String published, String cnnvd, String cvss, String defaults, String desct, String advice, String pocPosition, String ope, String key, String poc, String judge, String judgeMethod, String search) throws Exception {
        User user = (User) session.getAttribute("userInfo");
        Map<String, Object> options = new HashMap<>();
        options.put("pocPosition", pocPosition);
        options.put("ope", ope);
        options.put("key", key);
        options.put("poc", poc);
        options.put("judge", judge);
        options.put("judgeMethod", judgeMethod);
        options.put("search", search);
        Map<String, Object> results = this.engineService.insertWebPolicy(options);
        String id = ObjectUtil.getString(results.get("policyid"), "");
        if (StringUtils.isBlank(id)) {
            this.LOG.error("添加网站扫描策略policyid不能为空！");
            throw new UEException("策略添加失败，请检查网站引擎！");
        }
        try {
            this.webPoliciesMapper.insert(id, name, family, owasp2017, level, cwe, cve, StringUtils.isBlank(published) ? null : published, cnnvd, cvss, defaults, desct, advice, pocPosition, ope, key, poc, judge, judgeMethod, search, user.getId());
        } catch (Exception e) {
            this.engineService.delWebPolicy(id);
            this.LOG.error("新增网站扫描策略错误", e);
        }
        return id;
    }

    public Map<String, Object> getPoliciesById(String id) throws Exception {
        return this.webPoliciesMapper.getPoliciesById(id);
    }

    public Integer getCountByName(HttpSession session, String name) throws Exception {
        User user = (User) session.getAttribute("userInfo");
        return this.webPoliciesMapper.getCountByName(name, user.getId());
    }

    public void updLevelById(String id, String level) throws Exception {
        this.webPoliciesMapper.updLevelById(id, level);
    }
}
